package
module
Version:
v0.1.2
Opens a new window with list of versions in this module.
Published: Jun 17, 2019
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Tuna
Tuna is a gRPC server.
Installation
go get -u github.com/Kamva/tuna
Documentation
¶
GRPC is responsible for handling gRPC server.
New instantiate the GRPC handler.
Context returns the context used in gRPC.
Run starts the gRPC server on given address.
Server returns gRPC server.
func (g *GRPC) Shutdown()
Shutdown shutting down grpc server gracefully.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.